import React from 'react';
import {
  Image,
  Text,
  TouchableOpacity,
  View,
  StyleSheet,
  LogBox,
} from 'react-native';
import Header from './header';
import ParallaxScroll from './ParallaxScroll';
import Styles from './Style';
import Images from './images';
import {width, TOUCH_OPACITY, Colors} from './utils';

LogBox.ignoreLogs([
  'VirtualizedLists should never be nested inside plain ScrollViews with the same orientation - use another VirtualizedList-backed container instead.',
]);

const getBackground = () => (
  <View style={{backgroundColor: Colors.dark_gray}} />
);

const ParallaxHeader = (props) => {
  const {
    children,
    headerImage = '',
    leftImage = '',
    renderHeader: headerComponent,
    leftImageOnPress,
    headerImageHeight,
    headerImageWidth,
  } = props;
  const defaultHeaderHeight = 100;
  const defaultHeaderWidth = (width * 50) / 100;

  const openSearch = (location) => {};

  const defaultHeader = () => {
    return (
      <View style={styles.textInputContainerStyle}>
        <TouchableOpacity
          style={styles.searchTextStyle}
          activeOpacity={TOUCH_OPACITY}
          onPress={() => {}}>
          <View style={styles.searchView}>
            <Image source={Images.search} style={styles.searchIconStyle} />
            <Text
              numberOfLines={1}
              ellipsizeMode="tail"
              style={[styles.searchTextStyle, {flex: 1}]}>
              {'Search...'}
            </Text>
          </View>
        </TouchableOpacity>
      </View>
    );
  };

  return (
    <View style={Styles.homeContainer}>
      <ParallaxScroll
        style={{backgroundColor: Colors.dark_gray}}
        renderHeader={({height, animatedValue}) => (
          <Header
            headerImageHeight={
              isNaN(headerImageHeight) ? defaultHeaderHeight : headerImageHeight
            }
            headerImageWidth={
              isNaN(headerImageWidth) ? defaultHeaderWidth : headerImageWidth
            }
            headerImage={headerImage}
            leftImage={leftImage}
            leftImageOnPress={leftImageOnPress}
            renderHeader={
              typeof headerComponent === 'function'
                ? headerComponent()
                : defaultHeader()
            }
            onRef={(ref) => (headerRef = ref)}
            height={height}
            withAvatar
            animatedValue={animatedValue}
            onSearchClick={openSearch}
          />
        )}
        headerHeight={100}
        isHeaderFixed={true}
        parallaxHeight={120}
        useNativeDriver={true}
        isBackgroundScalable={true}
        headerBackgroundColor="transparent"
        headerFixedTransformY={30}
        renderParallaxBackground={getBackground}
        fadeOutParallaxBackground={false}
        fadeOutParallaxForeground={true}
        headerFixedBackgroundColor="transparent"
        parallaxBackgroundScrollSpeed={5}
        parallaxForegroundScrollSpeed={2.5}>
        {children}
      </ParallaxScroll>
    </View>
  );
};

export default ParallaxHeader;

const styles = StyleSheet.create({
  textInputContainerStyle: {
    flexDirection: 'row',
    justifyContent: 'center',
    alignItems: 'center',
    marginTop: 5,
    height: 40,
    width: '100%',
    borderRadius: 2,
    borderColor: '#000',
    borderWidth: StyleSheet.hairlineWidth,
  },
  searchTextStyle: {
    color: '#aaa',
    flex: 1,
    fontSize: 14,
    paddingRight: 5,
    textAlign: 'left',
    paddingLeft: 5,
  },
  searchDividerStyle: {
    width: 1,
    height: '100%',
    backgroundColor: Colors.dividerColor,
  },
  searchIconStyle: {
    alignItems: 'center',
    alignSelf: 'center',
    height: 20,
    width: 20,
    marginRight: 5,
    marginLeft: 5,
    resizeMode: 'contain',
    tintColor: '#2e2e2e',
  },
  searchView: {
    flexDirection: 'row',
    flex: 1,
    alignItems: 'center',
  },
});
