import React, { useEffect, useState } from "react";
import { Animated, View, StyleSheet } from "react-native";
import PropTypes from "prop-types";
import { width, Colors, getWidth } from "../utils";
import Images from "../images";

const Header = (props) => {
  const {
    withAvatar,
    animatedValue,
    leftImage,
    headerImage,
    renderHeader,
    leftImageOnPress,
    headerImageHeight,
    headerImageWidth,
  } = props;
  const logo = headerImage ? headerImage : Images.logo;
  const firstLetter = leftImage ? leftImage : Images.firstLetter;
  const [isShowSmallLogo, setIsShowSmallLogo] = useState(false);

  useEffect(() => {
    props.onRef(this);
  }, []);

  const opacity = withAvatar
    ? animatedValue.interpolate({
        inputRange: [0, headerImageHeight - 100],
        outputRange: [0, 1],
        extrapolate: "clamp",
      })
    : 1;

  const scale = withAvatar
    ? animatedValue.interpolate({
        inputRange: [0, 160],
        outputRange: [1, 0.8],
        extrapolateLeft: "clamp",
        extrapolateRight: "clamp",
      })
    : 1;

  const translateY = withAvatar
    ? animatedValue.interpolate({
        inputRange: [0, 160],
        outputRange: [0, 20],
        extrapolateLeft: "clamp",
        extrapolateRight: "clamp",
      })
    : 1;

  let wrapperStyle = {};

  if (withAvatar) {
    wrapperStyle = {
      alignItems: "center",
      justifyContent: "center",
    };
  }

  const getAvatar = () => {
    const avatarScale = animatedValue.interpolate({
      inputRange: [
        0,
        headerImageWidth <= 360
          ? headerImageHeight - 40
          : headerImageHeight - 48,
      ],
      outputRange: [1, headerImageWidth <= 360 ? 1 : 1],
      extrapolateRight: "clamp",
    });

    const avatarTranslateX = animatedValue.interpolate({
      inputRange: [-headerImageHeight + 48, 0, headerImageHeight - 48],
      outputRange: [0, 0, -getWidth(52)],
      extrapolateRight: "clamp",
    });

    const avatarTranslateY = animatedValue.interpolate({
      inputRange: [-headerImageHeight + 48, 0, headerImageHeight - 48],
      outputRange: [50, 0, headerImageWidth <= 360 ? 13 : 15],
      extrapolateRight: "clamp",
    });

    const textScale = animatedValue.interpolate({
      inputRange: [0, headerImageHeight],
      outputRange: [1, 1.15],
      extrapolateRight: "clamp",
    });

    const textTranslateX = animatedValue.interpolate({
      inputRange: [-headerImageHeight + 48, 0, headerImageHeight / 4],
      outputRange: [60, 0, 25],
      extrapolateRight: "clamp",
    });

    const textTranslateY = animatedValue.interpolate({
      inputRange: [-headerImageHeight + 48, 0, headerImageHeight - 48],
      outputRange: [45, 0, -30],
      extrapolateRight: "clamp",
    });

    var _value;
    animatedValue.addListener(({ value }) => {
      _value = value;
      if (_value >= 40) {
        if (!isShowSmallLogo) setIsShowSmallLogo(true);
      } else {
        if (isShowSmallLogo) setIsShowSmallLogo(false);
      }
    });

    return (
      <View style={styles.container}>
        <Animated.Image
          style={[
            styles.avatar,
            {
              transform: [
                { scale: avatarScale },
                { translateX: avatarTranslateX },
                { translateY: avatarTranslateY },
              ],
            },
          ]}
          source={isShowSmallLogo ? firstLetter : logo}
        />
        <Animated.View
          style={[
            styles.homeFormView,
            {
              transform: [
                { scale: textScale },
                { translateX: textTranslateX },
                { translateY: textTranslateY },
              ],
            },
          ]}
        >
          {renderHeader}
        </Animated.View>
      </View>
    );
  };

  return (
    <Animated.View
      style={[styles.wrapper, wrapperStyle]}
      pointerEvents="box-none"
    >
      <Animated.View
        style={[styles.background, { opacity }]}
        pointerEvents="box-none"
      />
      <Animated.View style={{ transform: [{ scale }, { translateY }] }}>
        {withAvatar ? getAvatar() : null}
      </Animated.View>
    </Animated.View>
  );
};

export default Header;

const styles = StyleSheet.create({
  container: {
    width: "100%",
    justifyContent: "center",
    alignItems: "center",
  },
  wrapper: {
    flex: 1,
    alignItems: "center",
    justifyContent: "center",
    backgroundColor: Colors.dark_gray,
    position: "relative",
    paddingRight: "4%",
  },
  background: {
    position: "absolute",
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    backgroundColor: Colors.dark_gray,
    justifyContent: "center",
  },
  avatar: {
    width: (width * 50) / 100,
    height: (width * 10) / 100,
    alignSelf: "center",
    marginTop: 20,
    resizeMode: "contain",
  },
  homeFormView: {
    paddingBottom: "4%",
    width: "92%",
    marginTop: 5,
    alignSelf: "center",
    marginLeft: "4%",
  },
  textInputContainerStyle: {
    flexDirection: "row",
    justifyContent: "center",
    alignItems: "center",
    marginTop: 5,
    height: 40,
    width: "100%",
    borderRadius: 2,
    borderColor: "#000",
    borderWidth: StyleSheet.hairlineWidth,
  },
  searchTextStyle: {
    color: "#aaa",
    flex: 1,
    fontSize: 14,
    paddingRight: 5,
    textAlign: "left",
    paddingLeft: 5,
  },
  searchDividerStyle: {
    width: 1,
    height: "100%",
    backgroundColor: Colors.dividerColor,
  },
  searchIconStyle: {
    alignItems: "center",
    alignSelf: "center",
    height: 20,
    width: 20,
    marginRight: 5,
    marginLeft: 5,
    resizeMode: "contain",
    tintColor: "#2e2e2e",
  },
  searchView: {
    flexDirection: "row",
    flex: 1,
    alignItems: "center",
  },
});

Header.propTypes = {
  height: PropTypes.number,
  onPress: PropTypes.func,
  withAvatar: PropTypes.bool,
  animatedValue: PropTypes.instanceOf(Animated.Value),
};

Header.defaultProps = {
  height: 50,
  withAvatar: false,
  animatedValue: new Animated.Value(0),
};
